FlutterBin class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBinaryFileMetadata(
String filePath) → Future< BinaryFileMetadata> - Gets comprehensive metadata of a binary file.
-
getBinaryFileVersion(
String filePath) → Future< String?> - Gets the version of a binary file.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited