stringTables property
Every StringFileInfo table found, in the order the image lists them.
Implementation
final List<PeStringTable> stringTables;
Every StringFileInfo table found, in the order the image lists them.
final List<PeStringTable> stringTables;